@@ -10,13 +10,13 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-""" Generic RBD connection utilities."""
+"""Generic RBD connection utilities."""
 
 import io
 from oslo_log import log as logging
 
 from os_brick import exception
-from os_brick.i18n import _, _LE, _LW
+from os_brick.i18n import _
 from os_brick import utils
 
 try:
@@ -106,7 +106,7 @@ class RBDVolume(object):
                                           snapshot=snapshot,
                                           read_only=read_only)
         except client.rbd.Error:
-            LOG.exception(_LE("error opening rbd image %s"), name)
+            LOG.exception("error opening rbd image %s", name)
             client.disconnect()
             raise
 
@@ -217,7 +217,7 @@ class RBDVolumeIOWrapper(io.RawIOBase):
         try:
             self._rbd_volume.image.flush()
         except AttributeError:
-            LOG.warning(_LW("flush() not supported in this version of librbd"))
+            LOG.warning("flush() not supported in this version of librbd")
 
     def fileno(self):
         """RBD does not have support for fileno() so we raise IOError.
@@ -227,9 +227,5 @@ class RBDVolumeIOWrapper(io.RawIOBase):
         """
         raise IOError(_("fileno() not supported by RBD()"))
 
-    # NOTE(dosaboy): if IO object is not closed explicitly, Python auto closes
-    # it which, if this is not overridden, calls flush() prior to close which
-    # in this case is unwanted since the rbd image may have been closed prior
-    # to the autoclean - currently triggering a segfault in librbd.
     def close(self):
         self.rbd_image.close()
